#include <Arduino.h>
#include <TimeLib.h>
#include <Adafruit_NeoPixel.h>

#define BOUTON_PIN 21
#define LED_PIN_1 12
#define LED_PIN_2 27
#define NUM_LEDS_1 12
#define NUM_LEDS_2 29
#define speakerPin 13
#define buttonPin 22
#define alarmHour 15
#define alarmMinute 29

Adafruit_NeoPixel strip1(NUM_LEDS_1, LED_PIN_1, NEO_GRB + NEO_KHZ800);
Adafruit_NeoPixel strip2(NUM_LEDS_2, LED_PIN_2, NEO_GRB + NEO_KHZ800);

bool boutonPresse = false;
bool ledsAllumees = false;
bool alarmActive = true; // Variable d'état pour l'alarme

void setup() {
  Serial.begin(9600);
  strip1.begin();
  strip1.show(); // Initialize all pixels to 'off'
  strip2.begin();
  strip2.show(); // Initialize all pixels to 'off'
  pinMode(BOUTON_PIN, INPUT_PULLUP);
  pinMode(buttonPin, INPUT_PULLUP); // Activer la résistance de pull-up interne
  pinMode(speakerPin, OUTPUT);

  setTime(15, 28, 55, 1, 1, 2024);
}

void loop() {
  // Gestion de l'allumage et de l'extinction des LEDs avec le bouton
  if (digitalRead(BOUTON_PIN) == LOW && !boutonPresse) {
    boutonPresse = true;
    if (!ledsAllumees) {
      allumerLEDs();
      ledsAllumees = true;
    } else {
      eteindreLEDs();
      ledsAllumees = false;
    }
    delay(250); // Anti-rebond du bouton
  }
  
  if (digitalRead(BOUTON_PIN) == HIGH && boutonPresse) {
    boutonPresse = false;
    delay(250); // Anti-rebond du bouton
  }

  if (!alarmActive) {
    // Si l'alarme a été désactivée, ne rien faire
    return;
  }

  int currentHour = hour();
  int currentMinute = minute();

  // Vérifie si l'heure actuelle correspond à l'heure de l'alarme
  if (currentHour == alarmHour && currentMinute == alarmMinute) {
    activerAlarme();
  }

  delay(1000); // Attends une seconde avant de vérifier à nouveau l'heure
}

void allumerLEDs() {
  // Allumer la première bande LED
  for (int i = 0; i < NUM_LEDS_1; i++) {
    strip1.setPixelColor(i, strip1.Color(255, 0, 0)); // Couleur blanche
    strip1.show();
    delay(80); // Ajuster la vitesse de défilement ici
  }

  // Attendre deux secondes
  delay(500);

  // Allumer la deuxième bande LED
  for (int i = 0; i < NUM_LEDS_2; i++) {
    if (i < 8) {
      strip2.setPixelColor(i, strip2.Color(255, 255, 0)); // Couleur jaune
    } else {
      strip2.setPixelColor(i, strip2.Color(0, 0, 255)); // Couleur bleue
    }
    strip2.show();
    delay(80); // Ajuster la vitesse de défilement ici
  }
}

void eteindreLEDs() {
  // Éteindre la première bande LED
  for (int i = 0; i < NUM_LEDS_1; i++) {
    strip1.setPixelColor(i, strip1.Color(0, 0, 0)); // Couleur noire pour éteindre
    strip1.show();
    delay(50); // Ajuster la vitesse de défilement ici
  }

  // Attendre deux secondes
  delay(500);

  // Éteindre la deuxième bande LED
  for (int i = 0; i < NUM_LEDS_2; i++) {
    strip2.setPixelColor(i, strip2.Color(0, 0, 0)); // Couleur noire pour éteindre
    strip2.show();
    delay(50); // Ajuster la vitesse de défilement ici
  }
}

void activerAlarme() {
  // Allume les LED en rouge
  for(int i=0; i<strip1.numPixels(); i++) {
    strip1.setPixelColor(i, strip1.Color(255, 0, 0));
  }
  strip1.show();

  for(int i=0; i<strip2.numPixels(); i++) {
    strip2.setPixelColor(i, strip2.Color(255, 0, 0));
  }
  strip2.show();

  // Active l'alarme en continu
  tone(speakerPin, 400);

  // Boucle jusqu'à ce que le bouton soit pressé
  while (digitalRead(buttonPin) != LOW) {
    delay(100); // Ajoute un petit délai pour éviter de lire le bouton trop fréquemment
  }

  // Bouton pressé, éteindre les LED et arrêter l'alarme
  for(int i=0; i<strip1.numPixels(); i++) {
    strip1.setPixelColor(i, strip1.Color(0, 0, 0));
  }
  strip1.show();

  for(int i=0; i<strip2.numPixels(); i++) {
    strip2.setPixelColor(i, strip2.Color(0, 0, 0));
  }
  strip2.show();

  noTone(speakerPin);
  alarmActive = false; // Désactive définitivement l'alarme
}
